<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddPaiement extends AbstractMigration
{
    public function change()
    {
        $this
            ->table("commande_statut", ['id' => false, 'primary_key' => ["commande_statut_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('commande_statut_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'signed' => false])
            ->addColumn('commande_statut_rang', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'commande_statut_id'])
            ->create();

        $this
            ->table("paiement", ['id' => false, 'primary_key' => ["paiement_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('paiement_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('paiement_rang', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'paiement_id'])
            ->addColumn('paiement_image', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'paiement_rang'])
            ->addColumn('actif_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'paiement_image', 'signed' => false])
            ->addColumn('paiement_total_debut', 'decimal', ['null' => false, 'precision' => 15, 'scale' => 2, 'after' => 'actif_id'])
            ->addColumn('paiement_total_fin', 'decimal', ['null' => false, 'precision' => 15, 'scale' => 2, 'after' => 'paiement_total_debut'])
            ->addColumn('paiement_type', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'paiement_total_fin'])
            ->addColumn('paiement_class', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'paiement_type'])
            ->addColumn('commande_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'paiement_class', 'signed' => false])
            ->addForeignKey('commande_statut_id', 'commande_statut', 'commande_statut_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('actif_id', 'actif', 'actif_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addIndex(['actif_id'], ['name' => "actif_id", 'unique' => false])
            ->addIndex(['commande_statut_id'], ['name' => "commande_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("paiement_boutique", ['id' => false, 'primary_key' => ["paiement_boutique_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('paiement_boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('paiement_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'paiement_boutique_id', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'paiement_id', 'signed' => false])
            ->addColumn('paiement_boutique_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_id'])
            ->addForeignKey('paiement_id', 'paiement', 'paiement_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['paiement_id', 'boutique_id'], ['name' => "paiement_id_2", 'unique' => true])
            ->addIndex(['paiement_id'], ['name' => "paiement_id", 'unique' => false])
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->addIndex(['paiement_boutique_statut_id'], ['name' => "paiement_boutique_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("paiement_nom", ['id' => false, 'primary_key' => ["paiement_nom_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('paiement_nom_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('paiement_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'paiement_nom_id', 'signed' => false])
            ->addColumn('paiement_nom_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'paiement_id'])
            ->addColumn('paiement_nom_description', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'paiement_nom_nom'])
            ->addColumn('paiement_nom_txt_template', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'paiement_nom_description'])
            ->addColumn('paiement_nom_txt_email', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'paiement_nom_txt_template'])
            ->addColumn('langue_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'paiement_nom_txt_email', 'signed' => false])
            ->addForeignKey('paiement_id', 'paiement', 'paiement_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addIndex(['langue_id', 'paiement_id'], ['name' => "langue_id_2", 'unique' => true])
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->addIndex(['paiement_id'], ['name' => "paiement_id", 'unique' => false])
            ->create();
    }
}
