<?php

namespace Form;

use Form\Constraint\Callback;
use Form\Constraint\Date;
use Form\Constraint\Mail;
use Form\Constraint\NotBlank;
use Form\Constraint\Phone;
use Form\Constraint\UnequalToField;

class ProfileForm extends Form
{
    function __construct()
    {
        parent::__construct();
        $texte = new \Texte();

        $this
            ->add(
                new Field(
                    "client_nom",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("nom_obligatoire", "Vous devez remplir le champ Nom."))
                )
            )
            ->add(
                new Field(
                    "client_prenom",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("prenom_obligatoire", "Vous devez remplir le champ Prénom."))
                )
            )
            ->add(
                new Field(
                    "client_telephone",
                    array(
                        "not_empty" => new NotBlank(),
                        "is_number" => new Phone(),
                    ),
                    array(
                        "not_empty" => $texte->getOneOrCreate("telephone_obligatoire", "Vous devez remplir le numéro de téléphone."),
                        "is_number" => $texte->getOneOrCreate("telephone_invalide", "La valeur remplie n'est pas un numéro de téléphone."),
                    )
                )
            )
            ->add(
                new Field(
                    "client_email",
                    array(
                        "not_empty"  => new NotBlank(),
                        "is_mail"    => new Mail(),
                        "dispo_mail" => new Callback(array("Client", "mailIsFree")),
                    ),
                    array(
                        "not_empty"  => $texte->getOneOrCreate("email_obligatoire", "Vous devez remplir le champs email."),
                        "is_mail"    => $texte->getOneOrCreate("email_invalide", "Vous devez utiliser un email correct."),
                        "dispo_mail" => $texte->getOneOrCreate("email_pris", "L'adresse email que vous avez renseigné est déjà utilisée."),
                    )
                )
            )
            ->add(
                new Field(
                    "client_ddn",
                    array(
                        "not_empty" => new NotBlank(),
                        "date_ddn"  => new Date("Y-m-d"),
                    ),
                    array(
                        "not_empty" => $texte->getOneOrCreate("ddn_obligatoire", "Vous devez remplir une date de naissance."),
                        "date_ddn"  => $texte->getOneOrCreate("ddn_invalide", "Date de naissance invalide."),
                    )
                )
            )
            /*->add(
                new Field(
                    "client_societe",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("societe_obligatoire", "Vous devez remplir le champ societe."))
                )
            )
            ->add(
                new Field(
                    "civilite_id",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("civilite_obligatoire", "Vous devez remplir le champ civilite."))
                )
            )
            ->add(
                new Field(
                    "adresse_rue",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("rue_obligatoire", "Vous devez remplir le champ rue."))
                )
            )
            ->add(
                new Field(
                    "adresse_cp",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("cp_obligatoire", "Vous devez remplir le champ code postal."))
                )
            )
            ->add(
                new Field(
                    "adresse_ville",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("ville_obligatoire", "Vous devez remplir le champ ville."))
                )
            )
            ->add(
                new Field(
                    "pays_id",
                    array("not_empty" => new NotBlank()),
                    array("not_empty" => $texte->getOneOrCreate("pays_obligatoire", "Vous devez choisir un pays."))
                )
            )
            ->add(
                new Field(
                    "adresse_telephone",
                    array(
                        "not_empty" => new NotBlank(),
                        "is_number" => new Phone(),
                    ),
                    array(
                        "not_empty" => $texte->getOneOrCreate("telephone_obligatoire", "Vous devez remplir le numéro de téléphone."),
                        "is_number" => $texte->getOneOrCreate("telephone_invalide", "La valeur remplie n'est pas un numéro de téléphone."),
                    )
                )
            )*/
        ;
    }

}